@@ -1,4 +1,4 @@
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 
 class MyCryptoUtils:
 
@@ -84,11 +84,11 @@ class MyCryptoUtils:
     if type(in2) == bytes or type(in2) == bytearray:
       in2 = in2.decode()[2:]
     if len(in1) > len(in2):
-      print("Length of input #1 is greater than #2. Trimming input #1.")
-      in1 = in1[:len(in2)]
+      print("Length of input #1 is greater than #2. Padding input #2 with leading zeros.")
+      in2 = in2.zfill(len(in1))
     if len(in2) > len(in1):
-      print("Length of input #2 is greater than #1. Trimming input #2.")
-      in2 = in2[:len(in1)]
+      print("Length of input #2 is greater than #1. Padding input #1 with leading zeros.")
+      in1 = in1.zfill(len(in2))
     xorStr = ""
     for bit1, bit2 in zip(in1, in2):
       xorStr += str(int(bit1) ^ int(bit2))
@@ -118,7 +118,7 @@ class MyCryptoUtils:
 
   def modInverse(self, a, m):
     for x in range(1, m):
-      if (((a%m) * (x%m)) % m ==1):
+      if (((a%m) * (x%m)) % m == 1):
         return x
     return -1
 
